local project_tbl, scan_sector = ...

local handler = {
	["pos"] = function(data)
		if (project_tbl.hasmdi) then return end

		local x, y = tonumber(data[1]), tonumber(data[2])
		local container = project_tbl.display_container
		if (x and y) then
			container.cx, container.cy = x, y
			HUD.cboxlayer.REFRESH = "YES"
			project_tbl:DestroyRegions()
			project_tbl:CreateRegions()
			gkini.WriteInt(project_tbl.config_name, "x", x)
			gkini.WriteInt(project_tbl.config_name, "y", y)
		else
			print("\127FFFFFFTargetlist position: "..container.cx.."x"..container.cy)
		end
	end,
	
	["font"] = function(data)
		local newsize = tonumber(data[1])
		if (newsize) then
			project_tbl.fontsize = newsize
			gkini.WriteInt(project_tbl.config_name, "FontSize", newsize)
			print("\127FFFFFFFont size has been changed to "..newsize..".")
			print("\127FFFFFFYou must reload the interface for the change to take effect.")
			
		else
			if (data[1] == "reset") then
				gkini.WriteInt(project_tbl.config_name, "FontSize", Font.H5)
				print("\127FFFFFFThe font size has been been reset to "..Font.H5..".")
				print("\127FFFFFFYou must reload the interface for the change to take effect.")
			else
				print("\127FFFFFFThe current font size is "..project_tbl.fontsize..".")
			end
		end
	end,
	
	["highlight"] = function(data)
		local r, g, b, a = tonumber(data[1]), tonumber(data[2]), tonumber(data[3]), tonumber(data[4])
		if (r and g and b) then
			a = a or 65
			project_tbl.current_target_color = string.format("%d %d %d %d *", r, g, b, a)
			gkini.WriteString(project_tbl.config_name, "Highlight", project_tbl.current_target_color)
		
		else
			if (data[1] == "reset") then
				project_tbl.current_target_color = project_tbl.default_target_color
				gkini.WriteString(project_tbl.config_name, "Highlight", project_tbl.current_target_color)
			else
				print("\127FFFFFFThe current highlight color is "..project_tbl.current_target_color:match("(.*) %*"))
			end
		end
	end,
	
	["rows"] = function(data)
		local newrows = tonumber(data[1])
		if (newrows) then
			--project_tbl.list_count = newrows -- if list_count is updated before a reload, it can cause problems with the existing display
			gkini.WriteInt(project_tbl.config_name, "List Count", newrows)
			print("\127FFFFFFThe number of rows has been changed to "..newrows..".")
			print("\127FFFFFFYou must reload the interface for the change to take effect.")
			
		else
			if (data[1] == "reset") then
				gkini.WriteInt(project_tbl.config_name, "List Count", 10)
				print("\127FFFFFFThe number of rows has been been reset to 10.")
				print("\127FFFFFFYou must reload the interface for the change to take effect.")
			else
				print("\127FFFFFFThe current number of rows is "..project_tbl.list_count..".")
			end
		end
	end,
	
	["width"] = function(data)
		local newsize = tonumber(data[1])
		if (newsize) then
			project_tbl.fontsize = newsize
			gkini.WriteInt(project_tbl.config_name, "Name Width", newsize)
			print("\127FFFFFFName width has been changed to "..newsize..".")
			print("\127FFFFFFYou must reload the interface for the change to take effect.")
			
		else
			if (data[1] == "reset") then
				gkini.WriteInt(project_tbl.config_name, "Name Width", 0)
				print("\127FFFFFFName width has been reset.")
				print("\127FFFFFFYou must reload the interface for the change to take effect.")
			else
				local width = project_tbl.name_width
				if (not width) then width = "unset (actual "..project_tbl.display[1][2][3][2].w..")" end
				print("\127FFFFFFThe current name width is "..width..".")
			end
		end
	end
}

local function cmd_processor(_, data)
	if (not data) then return end
	local cmd = string.lower(table.remove(data, 1))
	if (type(handler[cmd]) == "function") then handler[cmd](data) end
end

local function cycle_filter(_, data)
	if (data) then data = tonumber(data[1]) % 4 end
	project_tbl.filters:SetHighlight(project_tbl.filter + 1, false)
	project_tbl.filter = data or ((project_tbl.filter + 1) % 4)
	project_tbl.filters:SetHighlight(project_tbl.filter + 1, true)
	gkini.WriteInt(project_tbl.config_name, "Filter", project_tbl.filter)
end

local function cycle_faction_filter()
	project_tbl.faction_filter = (project_tbl.faction_filter + 1) % 4
	project_tbl.filters:SetHighlight(project_tbl.filter + 1, true)
	
end

local function change_target(i)
	if (project_tbl.shiplist[i]) then
		radar.SetRadarSelection(project_tbl.shiplist[i].nodeid, project_tbl.shiplist[i].objectid)
	end
end

local function target_next()
	local i = project_tbl.current_target_listindex or 0
	i = (i + 1) % project_tbl.list_count
	if (i == 0) then i = project_tbl.list_count end
	if (i > #project_tbl.shiplist) then i = 1 end
	change_target(i)
end

local function target_prev()
	local i = project_tbl.current_target_listindex or 0
	i = (i - 1) % project_tbl.list_count
	if (i == 0) then i = project_tbl.list_count end
	if (i > #project_tbl.shiplist) then i = #project_tbl.shiplist end
	change_target(i)
end

local verb = {[true] = "HIDING", [false] = "SHOWING"} -- reversed logic because the variable is hide_turrets
local verb_color = {[true] = "\127FF0000", [false] = "\12700FF00"}
local function toggleturrets()
	project_tbl.hide_turrets = not project_tbl.hide_turrets
	gkini.WriteInt(project_tbl.config_name, "Hide Turrets", project_tbl.hide_turrets and 1 or 0)
	print(string.format("%sTargetList is now %s%s%s turrets.", "\127FFFFFF", verb_color[project_tbl.hide_turrets], verb[project_tbl.hide_turrets], "\127FFFFFF"))
end


local function set_key_binds()

	for i = 1, project_tbl.list_count < 10 and project_tbl.list_count or 10 do 
		gkinterface.GKProcessCommand("bind "..(i % 10).." target"..i)
	end
	gkinterface.GKProcessCommand("bind - cyclefilter")
	gkinterface.GKProcessCommand("bind = cyclefactionfilter")
	gkinterface.GKProcessCommand("bind | toggleturrets")
end

for i = 1, project_tbl.list_count < 10 and project_tbl.list_count or 10 do 
	RegisterUserCommand("target"..i, function() change_target(i) end)
end
RegisterUserCommand("cyclefilter", cycle_filter)
RegisterUserCommand("cyclefactionfilter", cycle_faction_filter)
RegisterUserCommand("targetnext", target_next)
RegisterUserCommand("targetprev", target_prev)
RegisterUserCommand("toggleturrets", toggleturrets)
RegisterUserCommand("settargetbinds", set_key_binds)
RegisterUserCommand("targetlist", cmd_processor)
